<?php

require_once 'classes/placemarkiterator.php';


class KmlGenerator
{
	const GEWKT = 'GEOGCS["LL84",DATUM["WGS_1984",SPHEROID["WGS 84",6378137,298.25722293287],TOWGS84[0,0,0,0,0,0,0]],PRIMEM["Greenwich",0],UNIT["Degrees",1]]';

	private $args = null;
	private $site = null;
	private $layerDef = null;

	function __construct($args)
	{
		$this->args = $args;
		$this->site = new MgSiteConnection();
		$this->site->Open(new MgUserInformation('Anonymous', ''));
		
		$this->layerDef = parse_ini_file('layers/' . $args['layer'] . '.ini');
	}

	function GetLayerName()
	{
		return $this->layerDef['LayerName'];
	}

	function GetLayerDescription()
	{
		return $this->layerDef['LayerDesc'];
	}

	function GetStyle()
	{
		return file_get_contents('styles/' . $this->layerDef['Style'] . '.xml');
	}
	
	function GetPlacemarkIterator()
	{
		$featureService = $this->site->CreateService(MgServiceType::FeatureService);
		$featureSourceId = new MgResourceIdentifier($this->layerDef['FeatureSource']);
	
		$csTransforms = array();	
		$coordSysFactory = new MgCoordinateSystemFactory();
		$target = $coordSysFactory->Create(KmlGenerator::GEWKT);

		$scReader = $featureService->GetSpatialContexts($featureSourceId, false);
		while ($scReader->ReadNext())	
		{
			$scName = $scReader->GetName();
			$scWKT = $scReader->GetCoordinateSystemWkt();
			
			if ($scName != null && $scName != '' && $scWKT != null && $scWKT != '')
			{ 
				$source = $coordSysFactory->Create($scWKT);	
				$transform = new MgCoordinateSystemTransform($source, $target);
				
				$csTransforms[$scName] = $transform;
			}
		}
				
		$featureReader = $featureService->SelectFeatures($featureSourceId, $this->layerDef['FeatureClass'], null);
		
		return new PlacemarkIterator($featureReader, $csTransforms, $this->layerDef);
	}
	
}

?>
