<?php

require_once 'classes/markupmanager.php';

class MarkupEditor
{
	private $args = null;
	private $site = null;

	function __construct($args)
	{
		$this->args = $args;
		$this->site = new MgSiteConnection();
		$this->site->Open(new MgUserInformation($args['SESSION']));
	}

	function GetMarkupLayer()
	{
		return $this->args['OPENMARKUP'];
	}

	function GetMarkupName()
	{
		$resId = new MgResourceIdentifier($this->GetMarkupLayer());
		return $resId->GetName();
	}

	function GetMarkupFeatures()
	{
		$features = array();
		
		$featureService = $this->site->CreateService(MgServiceType::FeatureService);
		$featureSourceId = new MgResourceIdentifier('Library://Markup/' . $this->GetMarkupName() . '.FeatureSource');

		// LAB5: Insert your code here.
		
		
		
		
		return $features;
	}
	
	function GetTransform()
	{
		$coordSysFactory = new MgCoordinateSystemFactory();
		$resourceService = $this->site->CreateService(MgServiceType::ResourceService);
		
		$map = new MgMap();
		$map->Open($resourceService, $this->args['MAPNAME']);
		
		$source = $coordSysFactory->Create($map->GetMapSRS());	
		$target = $coordSysFactory->Create(MarkupManager::LL84WKT);
	
	 	return new MgCoordinateSystemTransform($source, $target);
	}

	function AddPoint()
	{		
		$vertices = explode(',', $this->args['GEOMETRY']);

		// LAB6: Insert your code here.
		
		
		$this->InsertMarkupFeature($propertyValues);
	}

	function AddLineString()
	{
		$geometryFactory = new MgGeometryFactory();
		$agfWriter = new MgAgfReaderWriter();
		
		$vertices = explode(',', $this->args['GEOMETRY']);
		$count = $vertices[0];

		$coords = new MgCoordinateCollection();
		for ($i = 0; $i < $count; $i++)
		{
			$coord = $geometryFactory->CreateCoordinateXY((double) $vertices[($i * 2) + 1], (double) $vertices[($i * 2) + 2]);
			$coords->Add($coord);
		}
		
		$lineString = $geometryFactory->CreateLineString($coords);
		$lineString = $lineString->Transform($this->GetTransform());
		$byteReader = $agfWriter->Write($lineString);
		
		$propertyValues = new MgPropertyCollection();
		$propertyValues->Add(new MgStringProperty('Text', $this->args['TEXT']));
		$propertyValues->Add(new MgGeometryProperty('Geometry', $byteReader));
		
		$this->InsertMarkupFeature($propertyValues);
	}

	function AddPolygon()
	{
		$geometryFactory = new MgGeometryFactory();
		$agfWriter = new MgAgfReaderWriter();
		
		$vertices = explode(',', $this->args['GEOMETRY']);
		$count = $vertices[0];

		$coords = new MgCoordinateCollection();
		for ($i = 0; $i < $count; $i++)
		{
			$coord = $geometryFactory->CreateCoordinateXY((double) $vertices[($i * 2) + 1], (double) $vertices[($i * 2) + 2]);
			$coords->Add($coord);
		}
		
		$linearRing = $geometryFactory->CreateLinearRing($coords);
		$polygon = $geometryFactory->CreatePolygon($linearRing, null);
		$polygon = $polygon->Transform($this->GetTransform());
		$byteReader = $agfWriter->Write($polygon);
		
		$propertyValues = new MgPropertyCollection();
		$propertyValues->Add(new MgStringProperty('Text', $this->args['TEXT']));
		$propertyValues->Add(new MgGeometryProperty('Geometry', $byteReader));
		
		$this->InsertMarkupFeature($propertyValues);
	}
	
	function InsertMarkupFeature($propertyValues)
	{
		$featureService = $this->site->CreateService(MgServiceType::FeatureService);		
		$featureSourceId = new MgResourceIdentifier('Library://Markup/' . $this->GetMarkupName() . '.FeatureSource');

		$commands = new MgFeatureCommandCollection();
		$commands->Add(new MgInsertFeatures('Markup', $propertyValues));

		$featureService->UpdateFeatures($featureSourceId, $commands, false);
	}
	
	function DeleteMarkup()
	{
		$featureService = $this->site->CreateService(MgServiceType::FeatureService);		
		$featureSourceId = new MgResourceIdentifier('Library://Markup/' . $this->GetMarkupName() . '.FeatureSource');

		$commands = new MgFeatureCommandCollection();
		$commands->Add(new MgDeleteFeatures('Markup', 'ID = ' . $this->args['MARKUPFEATURE']));

		$featureService->UpdateFeatures($featureSourceId, $commands, false);		
	}

	function UpdateMarkup()
	{
		$featureService = $this->site->CreateService(MgServiceType::FeatureService);		
		$featureSourceId = new MgResourceIdentifier('Library://Markup/' . $this->GetMarkupName() . '.FeatureSource');

		$propertyValues = new MgPropertyCollection();
		$propertyValues->Add(new MgStringProperty('Text', $this->args['TEXT']));

		$commands = new MgFeatureCommandCollection();
		$commands->Add(new MgUpdateFeatures('Markup', $propertyValues, 'ID = ' . $this->args['MARKUPFEATURE']));

		$featureService->UpdateFeatures($featureSourceId, $commands, false);		
	}

	function GetSelectionXML()
	{
		$selectionXML = '';
		
		$resourceService = $this->site->CreateService(MgServiceType::ResourceService);

		// LAB7: Insert your code here.

		
		return $selectionXML;
	}
}

?>