<?php

require_once 'classes/markupschemafactory.php';

class MarkupManager
{
	const LL84WKT = 'GEOGCS["LL84",DATUM["WGS_1984",SPHEROID["WGS 84",6378137,298.25722293287],TOWGS84[0,0,0,0,0,0,0]],PRIMEM["Greenwich",0],UNIT["Degrees",1]]';

	private $args = null;
	private $site = null;

	function __construct($args)
	{
		$this->args = $args;
		$this->site = new MgSiteConnection();
		$this->site->Open(new MgUserInformation($args['SESSION']));
	}

	function GetAvailableMarkup()
	{
		$markup = array();

		// LAB2: Insert your code here then uncomment the block below.
		

/* Uncomment this block!
		
	    $doc = DOMDocument::loadXML($resourceListXML);
		$nodeList = $doc->getElementsByTagName('ResourceId');
		
		foreach ($nodeList as $node)
		{
			$resourceId = new MgResourceIdentifier($node->nodeValue);
			$markup[$resourceId->ToString()] = $resourceId->GetName();
		}
*/
		asort($markup);
		
		return $markup;
	}
		
	function OpenMarkup()
	{
		$resourceService = $this->site->CreateService(MgServiceType::ResourceService);

		// LAB3: Insert your code here.
		// Parameters of Interest
		// 	$this->args['MAPNAME']
		//	$this->args['MARKUPLAYER']  - Resource ID of the Markup Layer to Open
		
		

		// Create the Layer Groups

		$markupGroup = null;
		$layerGroups = $map->GetLayerGroups();
		if ($layerGroups->Contains('_Markup'))
		{
			$markupGroup = $layerGroups->GetItem('_Markup');
		}
		else
		{
			$markupGroup = new MgLayerGroup('_Markup');
			$markupGroup->SetVisible(true);
			$markupGroup->SetLegendLabel('Markup');
			$markupGroup->SetDisplayInLegend(true);
			$layerGroups->Add($markupGroup);
		}

		// LAB3: Insert code to create the layer here.
		
		
		
	}

	function CloseMarkup()
	{
		$resourceService = $this->site->CreateService(MgServiceType::ResourceService);
		
		$map = new MgMap();
		$map->Open($resourceService, $this->args['MAPNAME']);

		// Add the Markup Layer

		$markupLayerResId = new MgResourceIdentifier($this->args['OPENMARKUP']);
		$index = $map->GetLayers()->IndexOf('_' . $markupLayerResId->GetName());
		$map->GetLayers()->RemoveAt($index);
		
		$map->Save($resourceService);
	}
	
	function CreateMarkup()
	{
		$resourceService = $this->site->CreateService(MgServiceType::ResourceService);
		$featureService = $this->site->CreateService(MgServiceType::FeatureService);

		$markupSdfResId = new MgResourceIdentifier('Library://Markup/' . $this->args['MARKUPNAME'] . '.FeatureSource');

		// LAB4: Insert your code here.
		// Parameters of Interest
		// 	$this->args['MARKUPNAME']   - Name of the Markup to create





		// Create the Markup Layer Definition

		$hexFgTransparency = sprintf("%02x", 255 * (100 - $this->args['FILLTRANSPARENCY']) / 100); // Convert % to an alpha value
		$hexBgTransparency = $this->args['FILLBACKTRANS'] ? "FF" : "00";							 // All or nothing
		$bold = array_key_exists('LABELBOLD', $this->args) ? "true" : "false";
		$italic = array_key_exists('LABELITALIC', $this->args) ? "true" : "false";
		$underline = array_key_exists('LABELUNDERLINE', $this->args) ? "true" : "false";
		
        $markupLayerDefinition = file_get_contents("templates/markuplayerdefinition.xml");
        $markupLayerDefinition = sprintf($markupLayerDefinition, 
			$markupSdfResId->ToString(),						//<ResourceId> - Feature Source
			$this->args['LABELSIZEUNITS'],						//<Unit> - Mark Label
			$this->args['LABELFONTSIZE'],						//<SizeX> - Mark Label Size
			$this->args['LABELFONTSIZE'],						//<SizeY> - Mark Label Size
			'FF' . $this->args['LABELFORECOLOR'],				//<ForegroundColor> - Mark Label
			'FF' . $this->args['LABELBACKCOLOR'],				//<BackgroundColor> - Mark Label
			$this->args['LABELBACKSTYLE'],						//<BackgroundStyle> - Mark Label
			$bold,												//<Bold> - Mark Label
			$italic,											//<Bold> - Mark Label
			$underline,											//<Underlined> - Mark Label
			$this->args['MARKERSIZEUNITS'],						//<Unit> - Mark
			$this->args['MARKERSIZE'],							//<SizeX> - Mark
			$this->args['MARKERSIZE'],							//<SizeY> - Mark
			$this->args['MARKERTYPE'],							//<Shape> - Mark
			'FF' . $this->args['MARKERCOLOR'],					//<ForegroundColor> - Mark
			'FF' . $this->args['MARKERCOLOR'],					//<Color> - Mark
			$this->args['LABELSIZEUNITS'],						//<Unit> - Line Label
			$this->args['LABELFONTSIZE'],						//<SizeX> - Line Label Size
			$this->args['LABELFONTSIZE'],						//<SizeY> - Line Label Size
			'FF' . $this->args['LABELFORECOLOR'],				//<ForegroundColor> - Line Label
			'FF' . $this->args['LABELBACKCOLOR'],				//<BackgroundColor> - Line Label
			$this->args['LABELBACKSTYLE'],						//<BackgroundStyle> - Line Label
			$bold,												//<Bold> - Line Label
			$italic,											//<Bold> - Line Label
			$underline,											//<Underlined> - Line Label			
			$this->args['LINEPATTERN'],							//<LineStyle> - Line
			$this->args['LINETHICKNESS'],						//<Thickness> - Line
			'FF' . $this->args['LINECOLOR'],					//<Color> - Line
			$this->args['LINESIZEUNITS'],						//<Unit> - Line
			$this->args['LABELSIZEUNITS'],						//<Unit> - Polygon Label
			$this->args['LABELFONTSIZE'],						//<SizeX> - Polygon Label Size
			$this->args['LABELFONTSIZE'],						//<SizeY> - Polygon Label Size
			'FF' . $this->args['LABELFORECOLOR'],				//<ForegroundColor> - Polygon Label
			'FF' . $this->args['LABELBACKCOLOR'],				//<BackgroundColor> - Polygon Label
			$this->args['LABELBACKSTYLE'],						//<BackgroundStyle> - Polygon Label
			$bold,												//<Bold> - Polygon Label
			$italic,											//<Bold> - Polygon Label
			$underline,											//<Underlined> - Polygon Label
			$this->args['FILLPATTERN'], 						//<FillPattern> - Fill
			$hexFgTransparency . $this->args['FILLFORECOLOR'], 	//<ForegroundColor> - Fill
			$hexBgTransparency . $this->args['FILLBACKCOLOR'], 	//<BackgroundColor> - Fill
			$this->args['BORDERPATTERN'],						//<LineStyle> - Fill
			$this->args['BORDERTHICKNESS'], 					//<Thickness> - Fill
			'FF' . $this->args['BORDERCOLOR'], 					//<Color> - Fill
			$this->args['BORDERSIZEUNITS']); 					//<Unit> - Fill

		$markupLayerResId = new MgResourceIdentifier('Library://Markup/' . $this->args['MARKUPNAME'] . '.LayerDefinition');
		
		// LAB4: Insert the rest of your code here.
		
		
		
	}
	
	function DeleteMarkup()
	{
		$resourceService = $this->site->CreateService(MgServiceType::ResourceService);

		$markupLayerResId = new MgResourceIdentifier($this->args['MARKUPLAYER']);
		$markupSdfResId = new MgResourceIdentifier('Library://Markup/' . $markupLayerResId->GetName() . '.FeatureSource');

		$resourceService->DeleteResource($markupLayerResId);
		$resourceService->DeleteResource($markupSdfResId);
	}

	function GetOpenMarkup()
	{
		$openMarkup = array();
		
		$resourceService = $this->site->CreateService(MgServiceType::ResourceService);
		
		$map = new MgMap();
		$map->Open($resourceService, $this->args['MAPNAME']);
		
		$layerGroups = $map->GetLayerGroups();
		if ($layerGroups->Contains('_Markup'))
		{
			$layers = $map->GetLayers();
			
			for ($i = 0; $i < $layers->GetCount(); $i++)
			{
				$layer = $layers->GetItem($i);
				if (($layer->GetGroup() != null) and ($layer->GetGroup()->GetName() == '_Markup'))
				{
					$openMarkup['Library://Markup/' . $layer->GetLegendLabel() . '.LayerDefinition'] = $layer->GetLegendLabel();
				}		
			}
			asort($openMarkup);			
		}				
		return $openMarkup;
	}	
}

?>